@@ -33,8 +33,15 @@ class AlgodClient:
         self.algod_address = algod_address
         self.headers = headers
 
-    def algod_request(self, method, requrl, params=None, data=None,
-                      headers=None, response_format="json"):
+    def algod_request(
+        self,
+        method,
+        requrl,
+        params=None,
+        data=None,
+        headers=None,
+        response_format="json",
+    ):
         """
         Execute a given request.
 
@@ -48,7 +55,7 @@ class AlgodClient:
         Returns:
             dict: loaded from json response body
         """
-        header = {}
+        header = {"User-Agent": "py-algorand-sdk"}
 
         if self.headers:
             header.update(self.headers)
@@ -57,17 +64,19 @@ class AlgodClient:
             header.update(headers)
 
         if requrl not in constants.no_auth:
-            header.update({
-                constants.algod_auth_header: self.algod_token
-            })
+            header.update({constants.algod_auth_header: self.algod_token})
 
         if requrl not in constants.unversioned_paths:
             requrl = api_version_path_prefix + requrl
         if params:
             requrl = requrl + "?" + parse.urlencode(params)
 
-        req = Request(self.algod_address+requrl, headers=header, method=method,
-                      data=data)
+        req = Request(
+            self.algod_address + requrl,
+            headers=header,
+            method=method,
+            data=data,
+        )
 
         try:
             resp = urlopen(req)
@@ -75,14 +84,16 @@ class AlgodClient:
             code = e.code
             e = e.read().decode("utf-8")
             try:
-                raise error.AlgodHTTPError(json.loads(e)["message"], code)
-            except:
+                e = json.loads(e)["message"]
+            finally:
                 raise error.AlgodHTTPError(e, code)
         if response_format == "json":
             try:
                 return json.load(resp)
             except Exception as e:
-                raise error.AlgodResponseError("Failed to parse JSON response from algod") from e
+                raise error.AlgodResponseError(
+                    "Failed to parse JSON response from algod"
+                ) from e
         else:
             return resp.read()
 
@@ -95,7 +106,7 @@ class AlgodClient:
         """
         req = "/accounts/" + address
         return self.algod_request("GET", req, **kwargs)
-    
+
     def asset_info(self, asset_id, **kwargs):
         """
         Return information about a specific asset.
@@ -105,7 +116,7 @@ class AlgodClient:
         """
         req = "/assets/" + str(asset_id)
         return self.algod_request("GET", req, **kwargs)
-    
+
     def application_info(self, application_id, **kwargs):
         """
         Return information about a specific application.
@@ -116,8 +127,9 @@ class AlgodClient:
         req = "/applications/" + str(application_id)
         return self.algod_request("GET", req, **kwargs)
 
-    def pending_transactions_by_address(self, address, limit=0, response_format="json",
-                                        **kwargs):
+    def pending_transactions_by_address(
+        self, address, limit=0, response_format="json", **kwargs
+    ):
         """
         Get the list of pending transactions by address, sorted by priority,
         in decreasing order, truncated at the end at MAX. If MAX = 0, returns
@@ -134,17 +146,19 @@ class AlgodClient:
             query["max"] = limit
         req = "/accounts/" + address + "/transactions/pending"
         res = self.algod_request(
-            "GET", req, params=query, response_format=response_format,
-            **kwargs)
+            "GET", req, params=query, response_format=response_format, **kwargs
+        )
         return res
 
-    def block_info(self, block=None, response_format="json", round_num=None, **kwargs):
+    def block_info(
+        self, block=None, response_format="json", round_num=None, **kwargs
+    ):
         """
         Get the block for the given round.
 
         Args:
             block (int): block number
-            response_format (str): the format in which the response is 
+            response_format (str): the format in which the response is
                 returned: either "json" or "msgpack"
             round_num (int, optional): alias for block; specify one of these
         """
@@ -152,7 +166,9 @@ class AlgodClient:
         if block is None and round_num is None:
             raise error.UnderspecifiedRoundError
         req = "/blocks/" + _specify_round_string(block, round_num)
-        res = self.algod_request("GET", req, query, response_format=response_format, **kwargs)
+        res = self.algod_request(
+            "GET", req, query, response_format=response_format, **kwargs
+        )
         return res
 
     def ledger_supply(self, **kwargs):
@@ -176,7 +192,9 @@ class AlgodClient:
         """
         if block_num is None and round_num is None:
             raise error.UnderspecifiedRoundError
-        req = "/status/wait-for-block-after/" + _specify_round_string(block_num, round_num)
+        req = "/status/wait-for-block-after/" + _specify_round_string(
+            block_num, round_num
+        )
         return self.algod_request("GET", req, **kwargs)
 
     def send_transaction(self, txn, **kwargs):
@@ -190,10 +208,12 @@ class AlgodClient:
         Returns:
             str: transaction ID
         """
-        assert not isinstance(txn, future.transaction.Transaction), \
-            f"Attempt to send UNSIGNED transaction {txn}"
-        return self.send_raw_transaction(encoding.msgpack_encode(txn),
-                                         **kwargs)
+        assert not isinstance(
+            txn, future.transaction.Transaction
+        ), "Attempt to send UNSIGNED transaction {}".format(txn)
+        return self.send_raw_transaction(
+            encoding.msgpack_encode(txn), **kwargs
+        )
 
     def send_raw_transaction(self, txn, **kwargs):
         """
@@ -208,12 +228,17 @@ class AlgodClient:
         """
         txn = base64.b64decode(txn)
         req = "/transactions"
-        headers = util.build_headers_from(kwargs.get("headers", False), {'Content-Type': 'application/x-binary'})
+        headers = util.build_headers_from(
+            kwargs.get("headers", False),
+            {"Content-Type": "application/x-binary"},
+        )
         kwargs["headers"] = headers
 
         return self.algod_request("POST", req, data=txn, **kwargs)["txId"]
 
-    def pending_transactions(self, max_txns=0, response_format="json", **kwargs):
+    def pending_transactions(
+        self, max_txns=0, response_format="json", **kwargs
+    ):
         """
         Return pending transactions.
 
@@ -227,10 +252,14 @@ class AlgodClient:
         if max_txns:
             query["max"] = max_txns
         req = "/transactions/pending"
-        res = self.algod_request("GET", req, params=query, response_format=response_format, **kwargs)
+        res = self.algod_request(
+            "GET", req, params=query, response_format=response_format, **kwargs
+        )
         return res
 
-    def pending_transaction_info(self, transaction_id, response_format="json", **kwargs):
+    def pending_transaction_info(
+        self, transaction_id, response_format="json", **kwargs
+    ):
         """
         Return transaction information for a pending transaction.
 
@@ -241,7 +270,9 @@ class AlgodClient:
         """
         req = "/transactions/pending/" + transaction_id
         query = {"format": response_format}
-        res = self.algod_request("GET", req, params=query, response_format=response_format, **kwargs)
+        res = self.algod_request(
+            "GET", req, params=query, response_format=response_format, **kwargs
+        )
         return res
 
     def health(self, **kwargs):
@@ -268,12 +299,14 @@ class AlgodClient:
         """
         serialized = []
         for txn in txns:
-            assert not isinstance(txn, future.transaction.Transaction), \
-                f"Attempt to send UNSIGNED transaction {txn}"
+            assert not isinstance(
+                txn, future.transaction.Transaction
+            ), "Attempt to send UNSIGNED transaction {}".format(txn)
             serialized.append(base64.b64decode(encoding.msgpack_encode(txn)))
 
-        return self.send_raw_transaction(base64.b64encode(
-                                         b''.join(serialized)), **kwargs)
+        return self.send_raw_transaction(
+            base64.b64encode(b"".join(serialized)), **kwargs
+        )
 
     def suggested_params(self, **kwargs):
         """Return suggested transaction parameters."""
@@ -288,8 +321,8 @@ class AlgodClient:
             res["genesis-id"],
             False,
             res["consensus-version"],
-            res["min-fee"]
-            )
+            res["min-fee"],
+        )
 
     def compile(self, source, **kwargs):
         """
@@ -304,10 +337,15 @@ class AlgodClient:
 
         """
         req = "/teal/compile"
-        headers = util.build_headers_from(kwargs.get("headers", False), { 'Content-Type': 'application/x-binary' })
+        headers = util.build_headers_from(
+            kwargs.get("headers", False),
+            {"Content-Type": "application/x-binary"},
+        )
         kwargs["headers"] = headers
 
-        return self.algod_request("POST", req, data=source.encode('utf-8'), **kwargs)
+        return self.algod_request(
+            "POST", req, data=source.encode("utf-8"), **kwargs
+        )
 
     def dryrun(self, drr, **kwargs):
         """
@@ -321,7 +359,10 @@ class AlgodClient:
             dict: loaded from json response body
         """
         req = "/teal/dryrun"
-        headers = util.build_headers_from(kwargs.get("headers", False), {'Content-Type': 'application/msgpack'})
+        headers = util.build_headers_from(
+            kwargs.get("headers", False),
+            {"Content-Type": "application/msgpack"},
+        )
         kwargs["headers"] = headers
         data = encoding.msgpack_encode(drr)
         data = base64.b64decode(data)
@@ -332,7 +373,7 @@ class AlgodClient:
         """Returns the entire genesis file."""
         req = "/genesis"
         return self.algod_request("GET", req, **kwargs)
-    
+
     def proof(self, round_num, txid, **kwargs):
         """
         Get the proof for a given transaction in a round.
@@ -344,6 +385,7 @@ class AlgodClient:
         req = "/blocks/{}/transactions/{}/proof".format(round_num, txid)
         return self.algod_request("GET", req, **kwargs)
 
+
 def _specify_round_string(block, round_num):
     """
     Return the round number specified in either 'block' or 'round_num'.
